@@ -6,7 +6,7 @@
 
 plotDS <- function(ds.obj,leps=FALSE,plot.ts=TRUE,plot.map=TRUE, plot.res=FALSE,
                    plot.rate=FALSE,add=FALSE,col="darkred",lwd=2,lty=1,
-                   direc="output/",main=NULL,sub=NULL,xlab=NULL,ylab=NULL) {
+                   direc="output/",main=NULL,sub=NULL,xlab=NULL,ylab=NULL,newplot=TRUE) {
 
 if (class(ds.obj)!="ds") stop("Need a 'ds' object!")
 attach(ds.obj)
@@ -49,25 +49,33 @@ yymm.o<-ds.obj$yy.o + (ds.obj$mm.o-0.5)/12 + (ds.obj$dd.o-0.5)/365.25
 yymm.gcm<-ds.obj$yy.gcm + (ds.obj$mm.gcm-0.5)/12 + (ds.obj$dd.gcm-0.5)/365.25
 
 #if ((!leps)  & (plot.map)) par(ask=TRUE)
+
+  col.tab=c(col,"darkblue","darkgreen","brown")
+  t.rng <- paste(range(ds.obj$yy.cal)[1],"-",range(ds.obj$yy.cal)[2])
+  ds.map <- list(tim=NULL,date=NULL,n.maps=NULL)
+  ds.map$tim<-month; ds.map$date<-t.rng; ds.map$n.maps=n.fld
+  for (i in 1:n.fld) {
+    eval(parse(text=paste("ds.map$lon.",i,"<-ds.obj$lon.",i,sep="")))
+    eval(parse(text=paste("ds.map$lat.",i,"<-ds.obj$lat.",i,sep="")))
+    eval(parse(text=paste("ds.map$map.",i,"<-t(ds.obj$X.",i,")",sep="")))
+  }
+  class(ds.map) <- "map"; attr(ds.map,"descr") <- "ds: large-scale pattern"
+
 if (!add) {
   if ( (leps) & (plot.map) ) {
     figname<- paste("predictor_",v.name,"_",location,"_",region,"_",
                   month,ex.tag,".eps",sep="")
     postscript(file = figname,onefile=TRUE,horizontal=FALSE,paper="a4")
-  } else newFig()
+  } else if (newplot) newFig()
   if (plot.map) {
-    par(ps=16,cex.sub=0.6,cex.main=0.7)
+    if (newplot) par(ps=16,cex.sub=0.6,cex.main=0.7)
     plot(c(floor(min(lons,na.rm=TRUE)),ceiling(max(lons,na.rm=TRUE))),
-         c(floor(min(lats,na.rm=TRUE)),ceiling(max(lats,na.rm=TRUE))),type="n",
-         main=main,sub=sub,xlab=xlab,ylab=ylab)
+                 c(floor(min(lats,na.rm=TRUE)),ceiling(max(lats,na.rm=TRUE))),type="n",
+                 main=main,sub=sub,xlab=xlab,ylab=ylab)
   }
 
-  col.tab=c("darkblue","darkred","darkgreen","brown")
-  t.rng <- paste(range(ds.obj$yy.cal)[1],"-",range(ds.obj$yy.cal)[2])
-  ds.map <- list(tim=NULL,date=NULL,n.maps=NULL)
-  ds.map$tim<-month; ds.map$date<-t.rng; ds.map$n.maps=n.fld
-  for (i in 1:n.fld) {
-    if (plot.map) {
+  if (plot.map) {
+    for (i in 1:n.fld) {
       eval(parse(text=paste("lines(c(min(ds.obj$lon.",i,"),max(ds.obj$lon.",i,")),",
                                 "c(min(ds.obj$lat.",i,"),min(ds.obj$lat.",i,")),",
                                 "col=col.tab[i],lty=2)",sep="")))
@@ -83,11 +91,7 @@ if (!add) {
       eval(parse(text=paste("contour(ds.obj$lon.",i,",ds.obj$lat.",i,",t(ds.obj$X.",i,
                  "),nlevels=7,add=TRUE,lwd=2,col=col.tab[i])",sep="")))
     }
-    eval(parse(text=paste("ds.map$lon.",i,"<-ds.obj$lon.",i,sep="")))
-    eval(parse(text=paste("ds.map$lat.",i,"<-ds.obj$lat.",i,sep="")))
-    eval(parse(text=paste("ds.map$map.",i,"<-t(ds.obj$X.",i,")",sep="")))
   }
-  class(ds.map) <- "map"; attr(ds.map,"descr") <- "ds: large-scale pattern"
 
 #  print("plotDS: HERE")
 
@@ -118,7 +122,23 @@ if (!add) {
       file.remove(figname)
     } 
   }
-
+} else if (plot.map) {
+      for (i in 1:n.fld) {
+      eval(parse(text=paste("lines(c(min(ds.obj$lon.",i,"),max(ds.obj$lon.",i,")),",
+                                "c(min(ds.obj$lat.",i,"),min(ds.obj$lat.",i,")),",
+                                "col=col.tab[i],lty=2)",sep="")))
+      eval(parse(text=paste("lines(c(min(ds.obj$lon.",i,"),max(ds.obj$lon.",i,")),",
+                                "c(max(ds.obj$lat.",i,"),max(ds.obj$lat.",i,")),",
+                                "col=col.tab[i],lty=2)",sep="")))
+      eval(parse(text=paste("lines(c(min(ds.obj$lon.",i,"),min(ds.obj$lon.",i,")),",
+                                "c(min(ds.obj$lat.",i,"),max(ds.obj$lat.",i,")),",
+                                "col=col.tab[i],lty=2)",sep="")))
+      eval(parse(text=paste("lines(c(max(ds.obj$lon.",i,"),max(ds.obj$lon.",i,")),",
+                                "c(min(ds.obj$lat.",i,"),max(ds.obj$lat.",i,")),",
+                                "col=col.tab[i],lty=2)",sep="")))
+      eval(parse(text=paste("contour(ds.obj$lon.",i,",ds.obj$lat.",i,",t(ds.obj$X.",i,
+                 "),nlevels=7,add=TRUE,lwd=2,col=col.tab[i])",sep="")))
+    }
 }
 
 if ((!add) & (plot.ts)) {
@@ -126,12 +146,12 @@ if ((!add) & (plot.ts)) {
     figname<- paste("scen_",v.name,"_",location,"_",region,"_",
                     month,ex.tag,".eps",sep="")
     postscript(file = figname,onefile=TRUE,horizontal=FALSE,paper="a4")
-  } else newFig()
-  par(ps=16,cex.sub=0.6,cex.main=0.7,cex.main=0.6)
+  } else if (newplot) newFig()
+  if (newplot) par(ps=16,cex.sub=0.6,cex.main=0.7,cex.main=0.6)
 
   plot(c(min(yymm.o[1],yymm.gcm[1]),yymm.gcm[length(yymm.gcm)]),
-       y.lim.tr,type="n",
-       main=main,sub=sub,xlab=xlab,ylab=ylab)
+         y.lim.tr,type="n",
+         main=main,sub=sub,xlab=xlab,ylab=ylab)
   grid()
 
 }
@@ -174,8 +194,8 @@ if (leps) {
   figname<- paste("tendency_",v.name,"_",location,"_",region,"_",
                 month,ex.tag,".eps",sep="")
   postscript(file = figname,onefile=TRUE,horizontal=FALSE,paper="a4")
-} else newFig()
-par(ps=16,cex.sub=0.6,cex.main=0.7)
+} else if (newplot) newFig()
+if (newplot) par(ps=16,cex.sub=0.6,cex.main=0.7)
 
 plot(c(min(yymm.gcm),max(yymm.gcm)),y.lim.tr,type="n",
      main=main,sub=sub,xlab=xlab,ylab=paste("rate of change in",ylab))
@@ -200,8 +220,8 @@ if (leps) {
   figname<- paste("residual_",v.name,"_",location,"_",region,"_",
                 month,ex.tag,".eps",sep="")
   postscript(file = figname,onefile=TRUE,horizontal=FALSE,paper="a4")
-} else newFig()
-par(ps=16,cex.sub=0.9,cex.main=0.7)
+} else if (newplot) newFig()
+if (newplot) par(ps=16,cex.sub=0.9,cex.main=0.7)
 plot(yymm.o,step.wise$residual,type="l",lwd=3,
      main=paste("Residual",
                 region,"] ->",v.name,")"),sub=sub,xlab=xlab,ylab=ylab)
@@ -216,8 +236,8 @@ if (leps) {
   figname<- paste("qq-residual_",v.name,"_",location,"_",region,"_",
                 month,".eps",ex.tag,sep="")
   postscript(file = figname,onefile=TRUE,horizontal=FALSE,paper="a4")
-} else newFig()
-par(ps=16,cex.sub=0.8,cex.main=0.85)
+} else if (newplot) newFig()
+if (newplot) par(ps=16,cex.sub=0.8,cex.main=0.85)
 qqnorm((step.wise$residual-mean(step.wise$residual,na.rm=TRUE))/
        sd(step.wise$residual,na.rm=TRUE))
 lines(c(-5,5),c(-5,5),col="grey",lty=2)
